@@ -18,6 +18,8 @@
  */
 package org.apache.bigtop.manager.server.model.dto;
 
+import org.apache.bigtop.manager.server.enums.PropertyAction;
+
 import lombok.Data;
 
 import java.io.Serializable;
@@ -29,9 +31,10 @@ public class PropertyDTO implements Serializable {
 
     private String value;
 
-    private String displayName;
-
     private String desc;
 
     private AttrsDTO attrs;
+
+    // Only exists in request body
+    private PropertyAction action;
 }
