@@ -34,4 +34,10 @@ public class RepoDTO {
     private String arch;
 
     private String baseUrl;
+
+    private String pkgName;
+
+    private String checksum;
+
+    private Integer type;
 }
