@@ -18,6 +18,8 @@
  */
 package org.apache.bigtop.manager.server.model.req;
 
+import org.apache.bigtop.manager.server.enums.PropertyAction;
+
 import lombok.Data;
 
 import jakarta.validation.constraints.NotBlank;
@@ -30,9 +32,13 @@ public class PropertyReq {
 
     private String value;
 
-    private String displayName;
-
     private String desc;
 
     private AttrsReq attrs;
+
+    /**
+     * Action to be performed on the property.
+     * This could be used to indicate operations like 'add', 'update', or 'delete'.
+     */
+    private PropertyAction action;
 }
