@@ -30,4 +30,10 @@ public class RepoVO {
     private String arch;
 
     private String baseUrl;
+
+    private String pkgName;
+
+    private String checksum;
+
+    private Integer type;
 }
