@@ -18,13 +18,15 @@
  */
 package org.apache.bigtop.manager.server.service;
 
-import com.fasterxml.jackson.databind.JsonNode;
+import org.apache.bigtop.manager.server.model.vo.ClusterMetricsVO;
+import org.apache.bigtop.manager.server.model.vo.HostMetricsVO;
+import org.apache.bigtop.manager.server.model.vo.ServiceMetricsVO;
 
 public interface MetricsService {
 
-    JsonNode queryAgentsHealthyStatus();
+    HostMetricsVO hostMetrics(Long id, String interval);
 
-    JsonNode queryAgentsInfo(Long id, String interval);
+    ClusterMetricsVO clusterMetrics(Long clusterId, String interval);
 
-    JsonNode queryClustersInfo(Long clusterId, String interval);
+    ServiceMetricsVO serviceMetrics(Long serviceId, String interval);
 }
