@@ -18,6 +18,7 @@
  */
 package org.apache.bigtop.manager.server.service;
 
+import org.apache.bigtop.manager.server.model.dto.ChangePasswordDTO;
 import org.apache.bigtop.manager.server.model.dto.UserDTO;
 import org.apache.bigtop.manager.server.model.vo.UserVO;
 
@@ -30,10 +31,25 @@ public interface UserService {
      */
     UserVO current();
 
+    /**
+     * Get a user
+     *
+     * @param id user id
+     * @return user
+     */
+    UserVO get(Long id);
+
     /**
      * Update a user
      *
      * @return user
      */
     UserVO update(UserDTO userDTO);
+
+    /**
+     * Change password
+     *
+     * @param changePasswordDTO changePasswordDTO
+     */
+    UserVO changePassword(ChangePasswordDTO changePasswordDTO);
 }
