@@ -21,8 +21,8 @@ import type { App } from 'vue'
 import router from '@/router'
 import pinia from '@/store'
 import i18n from '@/locales'
-import Antd, { message } from 'ant-design-vue'
-import components from '@/components/common'
+import { message } from 'ant-design-vue'
+import components from '@/components'
 import directives from '@/directives'
 import VueDOMPurifyHTML from 'vue-dompurify-html'
 
@@ -33,7 +33,6 @@ interface PluginOptions {
 export default {
   install(app: App, options: PluginOptions) {
     app.use(pinia)
-    app.use(Antd)
     app.use(router)
     app.use(i18n)
     app.use(directives)
