@@ -17,22 +17,22 @@
  * under the License.
  */
 
-import type { NavigationGuardNext, Router } from 'vue-router'
-import { useClusterStore } from '@/store/cluster'
-function setCommonGuard(router: Router) {
-  router.beforeEach(async (to, from, next) => {
-    if (to.name === 'Clusters' && from.name !== 'Login') {
-      checkClusterSelect(next)
-    } else {
-      next()
-    }
-  })
-}
+import type { Router } from 'vue-router'
 
-function checkClusterSelect(next: NavigationGuardNext) {
-  const clusterStore = useClusterStore()
-  clusterStore.clusterCount === 0 && clusterStore.loadClusters()
-  clusterStore.clusterCount === 0 && next({ name: 'Default' })
+function setCommonGuard(router: Router) {
+  const token = localStorage.getItem('Token') ?? sessionStorage.getItem('Token') ?? undefined
+
+  router.beforeEach(async (to, _from, next) => {
+    if (!token) {
+      return next()
+    }
+
+    if (to.name === 'Clusters' && token) {
+      return next({ name: 'Default' })
+    }
+
+    return next()
+  })
 }
 
 function createRouterGuard(router: Router) {
