@@ -23,7 +23,7 @@ export const componentsConfigProvider = {
     paddingMD: 16,
     paddingLG: 16,
     paddingContentHorizontalLG: 16,
-    colorTextHeading: 'rgba(0, 0,.0,1)',
+    colorTextHeading: 'rgba(0, 0,0,1)',
     fontWeightStrong: 500
   },
   Form: {
